
class UnknownColor(Exception):
    pass

class UnknownColorMod(Exception):
    pass

class InvalidWidth(Exception):
    pass

class InvalidHeight(Exception):
    pass

class ThereIsNoBody(Exception):
    pass
